@@ -3,7 +3,3 @@
 library(knitr)
 knit("vignettes/json-apis.Rmd.orig", "vignettes/json-apis.Rmd")
 knit("vignettes/json-paging.Rmd.orig", "vignettes/json-paging.Rmd")
-
-library(devtools)
-build_vignettes()
-
